# Copyright (c) 2010 Volvox Development Team
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"), to deal
# in the Software without restriction, including without limitation the rights
# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
# copies of the Software, and to permit persons to whom the Software is
# furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in
# all copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
# THE SOFTWARE.
#
# Author: Konstantin Lepa <konstantin.lepa@gmail.com>
#
# Find the Iconv includes and library
#
# This module defines
# ICONV_INCLUDE_DIR, where to find iconv include files, etc.
# ICONV_LIBRARIES, the libraries to link against to use Iconv.
# Iconv_FOUND, If false, do not try to use Iconv.

# also defined, but not for general use are
# Iconv_LIBRARY, where to find the Iconv library.

set(ICONV_H iconv.h)


find_path(ICONV_INCLUDE_DIR ${ICONV_H}
	PATHS  /usr/local/include
	       /usr/include
	       NO_DEFAULT_PATH
	DOC   "Path to the ${ICONV_H} file"
)

find_library(Iconv_LIBRARY NAMES iconv
	PATHS  /usr/local/lib
	       /usr/lib
	       NO_DEFAULT_PATH
	DOC   "Library for character set conversion"
)

if(ICONV_INCLUDE_DIR AND Iconv_LIBRARY)
	set(Iconv_FOUND TRUE)
else(ICONV_INCLUDE_DIR AND Iconv_LIBRARY)
	set(Iconv_FOUND FALSE)
endif(ICONV_INCLUDE_DIR AND Iconv_LIBRARY)

if(Iconv_FOUND)
	if(NOT Iconv_FIND_QUIETLY)
		message(STATUS "Found Iconv: ${Iconv_LIBARY}")
	endif(NOT Iconv_FIND_QUIETLY)
else(Iconv_FOUND)
	if("${CMAKE_SYSTEM_NAME}" MATCHES "FreeBSD")
		if(NOT Iconv_FIND_QUIETLY)
			if(Iconv_FIND_REQUIRED)
				message(FATAL_ERROR "Could not find the Iconv Library")
			else(Iconv_FIND_REQUIRED)
				message(STATUS "Could not find the Iconv Library")
			endif(Iconv_FIND_REQUIRED)
		endif(NOT Iconv_FIND_QUIETLY)
	else("${CMAKE_SYSTEM_NAME}" MATCHES "FreeBSD")
		set(Iconv_LIBRARY "")
	endif("${CMAKE_SYSTEM_NAME}" MATCHES "FreeBSD")
endif(Iconv_FOUND)

mark_as_advanced(ICONV_INCLUDE_DIR Iconv_LIBRARY)

