// Copyright (c) 2010 Volvox Development Team
//
// Permission is hereby granted, free of charge, to any person obtaining a copy
// of this software and associated documentation files (the "Software"), to deal
// in the Software without restriction, including without limitation the rights
// to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
// copies of the Software, and to permit persons to whom the Software is
// furnished to do so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in
// all copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
// THE SOFTWARE.
//
// Author: Konstantin Lepa <konstantin.lepa@gmail.com>

#include "xml-element.hpp"
#include "xml-handler.hpp"
#include "xml-validator.hpp"

namespace simplexml
{

XMLHandler::XMLHandler() :
	currNode_(NULL), root_(NULL), copied_(false)
{ ;; }


XMLHandler::XMLHandler(XMLElement *root) :
	currNode_(NULL), root_(root), copied_(true)
{ ;; }


XMLHandler::~XMLHandler() throw()
{
	if (!copied_) { delete root_; }
}


INT_32 XMLHandler::StartElement(const std::string &elem, UINT_32 /*level*/,
	                            const std::vector<XMLAttr> &attr,
                                UINT_32 line, UINT_32 column)
{
	XMLElement *element = new XMLElement(currNode_, elem, line, column);

	if (currNode_) { currNode_->AddChild(element); }
	currNode_ = element;

	if (root_ == NULL) { root_ = currNode_; }

	const std::vector<XMLAttr>::const_iterator end = attr.end();
	std::vector< XMLAttr >::const_iterator it = attr.begin();

	for (; it != end; ++it)
	{
		currNode_->SetAttr(it->name, it->value);
	}

	return 0;
}


INT_32 XMLHandler::EndElement(const std::string &/*elem*/, UINT_32 /*level*/,
                              UINT_32 /*line*/, UINT_32 /*column*/)
{
	currNode_ = currNode_->Parent();

	return 0;
}


INT_32 XMLHandler::Characters(const std::string &/*data*/, UINT_32 /*level*/,
                              UINT_32 /*line*/, UINT_32 /*column*/)
{
	return 0;
}


void XMLHandler::ParseError(const std::string &/*reason*/, UINT_32 /*line*/,
                            UINT_32 /*column*/)
{ ;; }


void XMLHandler::Validate(const XMLValidator &validator) const
{
	validator.Validate(root_);
}

} // namespace simplexml

