// Copyright (c) 2010 Volvox Development Team
//
// Permission is hereby granted, free of charge, to any person obtaining a copy
// of this software and associated documentation files (the "Software"), to deal
// in the Software without restriction, including without limitation the rights
// to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
// copies of the Software, and to permit persons to whom the Software is
// furnished to do so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in
// all copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
// THE SOFTWARE.
//
// Author: Konstantin Lepa <konstantin.lepa@gmail.com>

#ifndef XMLPARSER_XML_UTILS_HPP_
#define XMLPARSER_XML_UTILS_HPP_

/**
	@file xml-utils.hpp
	Some XML utils defines
 */

#include "xml-element.hpp"

#include <utility>
#include <locale>
#include <string.h>

namespace simplexml
{

/**
	@addtogroup xmlgroup
	@{
	@defgroup xmlutilgroup XML Utils
	@{
 */

/**
	Functor, that find element in xml tree.
 */
class XMLElementFinder :
	public std::binary_function<const simplexml::XMLElement *, std::string, bool>
{
public:
	bool operator()(const simplexml::XMLElement *elem,
	                const std::string &str) const
	{
		if (strcasecmp(elem->Name().c_str(), str.c_str()) == 0)
		{ return true; }

		return false;
	}
}; // class XMLElementFinder


/**
	Functor, that find element in xml tree of specification.
 */
class XMLSpecElementFinder :
	public std::binary_function<const simplexml::XMLElement *, std::string, bool>
{
public:
	bool operator()(const simplexml::XMLElement *elem, const std::string &str) const
	{
		CCHAR_P specStr = elem->GetAttr("name").AsString().c_str();
		if (strcasecmp(specStr, str.c_str()) == 0) { return true; }

		return false;
	}
}; // class XMLSpecElementFinder


/**
	Functor, that convert string to lower case.
 */
struct ToLower : std::binary_function<CHAR_8, std::locale, CHAR_8>
{
	char operator ()(CHAR_8 c, const std::locale &loc) const
	{
		return std::tolower(c, loc);
	}
}; // struct ToLower

/** @} @} */

} // namespace simplexml

#endif // XMLPARSER_XML_UTILS_HPP_

